<?php

namespace Drupal\spammaster\Controller;

use Drupal\Core\Controller\ControllerBase;
use Symfony\Component\HttpFoundation\RequestStack;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\State\StateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\spammaster\SpamMasterActionService;

/**
 * Class controller.
 */
class SpamMasterActionController extends ControllerBase {

  /**
   * Symfony\Component\HttpFoundation\RequestStack definition.
   *
   * @var \Symfony\Component\HttpFoundation\RequestStack
   */
  protected $requestStack;

  /**
   * The Config Factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * The state.
   *
   * @var \Drupal\Core\State\StateInterface
   */
  protected $state;

  /**
   * The SpamMasterActionService Service.
   *
   * @var \Drupal\spammaster\SpamMasterActionService
   */
  protected $actionService;

  /**
   * {@inheritdoc}
   */
  public function __construct(RequestStack $requestStack, ConfigFactoryInterface $configFactory, StateInterface $state, SpamMasterActionService $actionService) {
    $this->requestStack = $requestStack;
    $this->configFactory = $configFactory;
    $this->state = $state;
    $this->actionService = $actionService;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('request_stack'),
      $container->get('config.factory'),
      $container->get('state'),
      $container->get('spammaster.action_service')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function spamMasterToAct() {

    $spammaster_settings = $this->configFactory->getEditable('spammaster.settings');
    $spammaster_license = $spammaster_settings->get('spammaster.license_key');
    $spammaster_status = $this->state->get('spammaster.license_status');
    $spammaster_db_protection_hash = $this->state->get('spammaster.spam_master_db_protection_hash');
    $this->state->set('spammaster.new_options', '1');
    if ($spammaster_status == 'VALID' || $spammaster_status == 'MALFUNCTION_1' || $spammaster_status == 'MALFUNCTION_2') {
      // Get current request.
      $spamPost = $this->requestStack->getCurrentRequest();
      // Check method.
      $spamMethod = $spamPost->getMethod();
      if ('POST' === $spamMethod) {
        // Get post content, fosdasse este caralho partiu-me a tola.
        $spamContent = $spamPost->getContent();
        $spamParams = json_decode($spamContent, TRUE);
        // Check first parameter.
        $spammasterOne = $spamParams['k'];
        $spammasterTwo = $spamParams['h'];
        if (isset($spammasterOne) && isset($spammasterTwo)) {
          if (empty($spammasterOne)) {
            return [
              '#markup' => $this->t('Silence is Golden. Request k. 401'),
            ];
          }
          if (empty($spammasterTwo)) {
            return [
              '#markup' => $this->t('Silence is Golden. Request h. 401'),
            ];
          }
          if (!empty($spammasterOne) && !empty($spammasterTwo)) {
            if ($spammasterOne == $spammaster_license && $spammasterTwo == $spammaster_db_protection_hash) {
              // Call action service.
              $spama = '1';
              $spammaster_action_service = $this->actionService;
              $spammaster_action_service->spamMasterAct($spama);
              return [
                '#markup' => $this->t('Successful Transfer. 200'),
              ];
            }
            else {
              return [
                '#markup' => $this->t('Not able to proceed in third order. Status. 401'),
              ];
            }
          }
        }
        else {
          return [
            '#markup' => $this->t('Silence is Golden. Status. 401'),
          ];
        }
      }
      else {
        return [
          '#markup' => $this->t('Not able to proceed in second order. Status. 401'),
        ];
      }
    }
    else {
      return [
        '#markup' => $this->t('Not able to proceed in first order. Status. 401'),
      ];
    }
  }

}
