<?php

namespace Drupal\spammaster;

use Drupal\Core\Database\Connection;
use Drupal\Core\Messenger\MessengerInterface;
use Symfony\Component\HttpFoundation\RequestStack;
use GuzzleHttp\Client;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\State\StateInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\Component\Serialization\Json;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Class service.
 */
class SpamMasterLicService {
  use StringTranslationTrait;

  /**
   * The database connection object.
   *
   * @var \Drupal\Core\Database\Connection
   */
  protected $connection;

  /**
   * The Messenger service.
   *
   * @var \Drupal\Core\Messenger\MessengerInterface
   */
  protected $messenger;

  /**
   * Symfony\Component\HttpFoundation\RequestStack definition.
   *
   * @var \Symfony\Component\HttpFoundation\RequestStack
   */
  protected $requestStack;

  /**
   * Client.
   *
   * @var \GuzzleHttp\Client
   */
  protected $httpClient;

  /**
   * The Config Factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * The state.
   *
   * @var \Drupal\Core\State\StateInterface
   */
  protected $state;

  /**
   * The SpamMasterMailService Service.
   *
   * @var \Drupal\spammaster\SpamMasterMailService
   */
  protected $mailService;

  /**
   * The SpamMasterLicService service.
   *
   * @var \Drupal\spammmaster\SpamMasterLicService
   */
  protected $spamKey;

  /**
   * The SpamMasterLicService service.
   *
   * @var \Drupal\spammmaster\SpamMasterLicService
   */
  protected $spamCron;

  /**
   * The SpamMasterActionService Service.
   *
   * @var \Drupal\spammaster\SpamMasterActionService
   */
  protected $actionService;

  /**
   * {@inheritdoc}
   */
  public function __construct(Connection $connection, MessengerInterface $messenger, RequestStack $requestStack, Client $httpClient, ConfigFactoryInterface $configFactory, StateInterface $state, SpamMasterMailService $mailService, SpamMasterActionService $actionService) {
    $this->connection = $connection;
    $this->messenger = $messenger;
    $this->requestStack = $requestStack;
    $this->httpClient = $httpClient;
    $this->configFactory = $configFactory;
    $this->state = $state;
    $this->mailService = $mailService;
    $this->actionService = $actionService;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('database'),
      $container->get('messenger'),
      $container->get('request_stack'),
      $container->get('http_client'),
      $container->get('config.factory'),
      $container->get('state'),
      $container->get('spammaster.mail_service'),
      $container->get('spammaster.action_service')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function spamMasterLicManualCreation() {

    // Get variables.
    $site_settings = $this->configFactory->getEditable('system.site');
    $spammaster_site_name = $site_settings->get('name');
    $spammaster_admin_email = $site_settings->get('mail');
    $spammaster_settings = $this->configFactory->getEditable('spammaster.settings');
    $spammaster_license = $spammaster_settings->get('spammaster.license_key');
    $spammaster_version = $this->state->get('spammaster.version');
    $spammaster_type = $this->state->get('spammaster.type');
    $spam_master_auto_update = $this->state->get('spammaster.spam_master_auto_update');
    $spam_master_db_protection_hash = $this->state->get('spammaster.spam_master_db_protection_hash');
    if (empty($spam_master_db_protection_hash)) {
      $spam_master_auto_update = 'false';
      $spam_master_db_protection_hash = substr(md5(uniqid(mt_rand(), TRUE)), 0, 64);
      if (empty($spam_master_db_protection_hash)) {
        $spam_master_db_protection_hash = 'md5-' . date('YmdHis');
      }
      $updated_values = [
        'spammaster.spam_master_auto_update' => $spam_master_auto_update,
        'spammaster.spam_master_db_protection_hash' => $spam_master_db_protection_hash,
      ];
      $this->state->setMultiple($updated_values);
    }
    // Prepare date.
    $spammaster_date = date('Y-m-d H:i:s');
    $spam_master_short_date = date('Y-m-d');
    $lazy_values = [
      'spammaster.spam_master_license_sync_date' => $spam_master_short_date,
      'spammaster.spam_master_license_sync_run' => '0',
    ];
    $this->state->setMultiple($lazy_values);
    $spammaster_platform = 'Drupal';
    $spammaster_platform_version = \Drupal::VERSION;
    $spammaster_platform_type = 'NO';
    $spammaster_n_websites = '0';
    $spammaster_multisite_joined = $spammaster_platform_type . ' - ' . $spammaster_n_websites;
    $spamCron = "MAN";
    $spammaster_site_url = $this->requestStack->getCurrentRequest()->getHost();
    $address_unclean = $spammaster_site_url;
    $address = preg_replace('#^https?://#', '', $address_unclean);
    if (isset($_SERVER['SERVER_ADDR'])) {
      $spammaster_ip = substr($_SERVER['SERVER_ADDR'], 0, 48);
      // Should bot be localhost.
      if (empty($spammaster_ip) || '0' === $spammaster_ip || '127.0.0.1' === $spammaster_ip) {
        if (isset($_SERVER['SERVER_NAME'])) {
          $spam_master_ip_gethostbyname = gethostbyname($_SERVER['SERVER_NAME']);
          $spammaster_ip = substr($spam_master_ip_gethostbyname, 0, 48);
          if (empty($spam_master_ip_gethostbyname) || '0' === $spam_master_ip_gethostbyname) {
            $spam_master_urlparts = parse_url($spammaster_site_url);
            $spam_master_hostname_temp = $spam_master_urlparts['host'];
            $spam_master_result = dns_get_record($spam_master_hostname_temp, DNS_A);
            $spammaster_ip = substr($spam_master_result[0]['ip'], 0, 48);
          }
        }
        else {
          $spammaster_ip = 'I 000';
        }
      }
      $spammaster_hostname = substr(gethostbyaddr($_SERVER['SERVER_ADDR']), 0, 256);
      if (empty($spammaster_hostname) || '0' === $spammaster_hostname || '127.0.0.1' === $spammaster_hostname) {
        if (isset($_SERVER['SERVER_NAME'])) {
          $spam_master_ho_gethostbyname = gethostbyname($_SERVER['SERVER_NAME']);
          $spammaster_hostname = substr($spam_master_ho_gethostbyname, 0, 256);
          if (empty($spam_master_ho_gethostbyname) || '0' === $spam_master_ho_gethostbyname) {
            $spam_master_urlparts = parse_url($spammaster_site_url);
            $spam_master_hostname_temp = $spam_master_urlparts['host'];
            $spam_master_result = dns_get_record($spam_master_hostname_temp, DNS_A);
            $spammaster_hostname = substr($spam_master_result[0]['ip'], 0, 256);
          }
        }
        else {
          $spammaster_hostname = 'H 000';
        }
      }
    }
    else {
      if (isset($_SERVER['SERVER_NAME'])) {
        $spam_master_ip_gethostbyname = gethostbyname($_SERVER['SERVER_NAME']);
        $spammaster_ip = substr($spam_master_ip_gethostbyname, 0, 48);
        if (empty($spam_master_ip_gethostbyname) || '0' === $spam_master_ip_gethostbyname) {
          $spam_master_urlparts = parse_url($spammaster_site_url);
          $spam_master_hostname_temp = $spam_master_urlparts['host'];
          $spam_master_result = dns_get_record($spam_master_hostname_temp, DNS_A);
          $spammaster_ip = substr($spam_master_result[0]['ip'], 0, 48);
        }
        else {
          $spammaster_ip = 'I 001';
        }
        $spam_master_ho_gethostbyname = gethostbyname($_SERVER['SERVER_NAME']);
        $spammaster_hostname = substr($spam_master_ho_gethostbyname, 0, 256);
        if (empty($spam_master_ho_gethostbyname) || '0' === $spam_master_ho_gethostbyname) {
          $spam_master_urlparts = parse_url($spammaster_site_url);
          $spam_master_hostname_temp = $spam_master_urlparts['host'];
          $spam_master_result = dns_get_record($spam_master_hostname_temp, DNS_A);
          $spammaster_hostname = substr($spam_master_result[0]['ip'], 0, 256);
        }
        else {
          $spammaster_hostname = 'H 001';
        }
      }
      else {
        $spammaster_ip = 'I 002';
        $spammaster_hostname = 'H 002';
      }
    }

    // Get buffer count.
    $spammaster_buffer_size = $this->connection->select('spammaster_threats', 'u');
    $spammaster_buffer_size->fields('u', ['threat']);
    $spammaster_buffer_size_result = $spammaster_buffer_size->countQuery()->execute()->fetchField();
    if (empty($spammaster_buffer_size_result)) {
      $spammaster_buffer_size_result = '1';
    }
    // Get white count.
    $spammaster_white_size = $this->connection->select('spammaster_white', 'u');
    $spammaster_white_size->fields('u', ['white_']);
    $spammaster_white_size_result = $spammaster_white_size->countQuery()->execute()->fetchField();
    if (empty($spammaster_white_size_result)) {
      $spammaster_white_size_result = '0';
    }
    // Get logs count.
    $spammaster_spam_watch_query = $this->connection->select('spammaster_keys', 'u');
    $spammaster_spam_watch_query->fields('u', ['spamkey']);
    $spammaster_spam_watch_result = $spammaster_spam_watch_query->countQuery()->execute()->fetchField();
    if (empty($spammaster_spam_watch_result)) {
      $spammaster_spam_watch_result = '0';
    }

    // Encode ssl post link security.
    $spammaster_license_url = 'aHR0cHM6Ly93d3cuc3BhbW1hc3Rlci5vcmcvd3AtY29udGVudC9wbHVnaW5zL3NwYW0tbWFzdGVyLWFkbWluaXN0cmF0b3IvaW5jbHVkZXMvbGljZW5zZS9nZXRfbGljLnBocA==';

    // Call drupal hhtpclient.
    $client = $this->httpClient;
    // Post data.
    $request = $client->post(base64_decode($spammaster_license_url), [
      'form_params' => [
        'spam_license_key' => $spammaster_license,
        'platform' => $spammaster_platform,
        'platform_version' => $spammaster_platform_version,
        'platform_type' => $spammaster_multisite_joined,
        'spam_master_version' => $spammaster_version,
        'spam_master_type' => $spammaster_type,
        'blog_name' => $spammaster_site_name,
        'blog_address' => $address,
        'blog_email' => $spammaster_admin_email,
        'blog_hostname' => $spammaster_hostname,
        'blog_ip' => $spammaster_ip,
        'blog_up' => $spam_master_auto_update,
        'spam_master_db' => $spam_master_db_protection_hash,
        'spam_master_buffer' => $spammaster_buffer_size_result,
        'spam_master_white' => $spammaster_white_size_result,
        'spam_master_logs' => $spammaster_spam_watch_result,
        'spam_master_cron' => $spamCron,
      ],
    ]);
    // Decode json data.
    $response = Json::decode($request->getBody());
    if (empty($response)) {
      $spammaster_type_set = 'EMPTY';
      $spammaster_status = 'INACTIVE';
      $spammaster_protection_total_number = '0';
      $spammaster_alert_level_received = '';
      $spammaster_alert_level_p_text = '';
      $spam_master_attached = '';
    }
    else {
      $spammaster_status = $response['status'];
      if ('MALFUNCTION_3' === $spammaster_status) {
        $spammaster_type_set = 'MALFUNCTION_3';
        $spammaster_protection_total_number = 'MALFUNCTION_3';
        $spammaster_alert_level_received = 'MALFUNCTION_3';
        $spammaster_alert_level_p_text = 'MALFUNCTION_3';
        $spam_master_attached = '';
      }
      else {
        $spammaster_type_set = $response['type'];
        $spammaster_protection_total_number = $response['threats'];
        $spammaster_alert_level_received = $response['alert'];
        $spammaster_alert_level_p_text = $response['percent'];
        $spam_master_attached = $response['attached'];

        $spama = $response['a'];
        if ('1' === $spama) {
          $this->state->set('spammaster.new_options', '1');
          $this->connection->insert('spammaster_keys')->fields([
            'date' => $spammaster_date,
            'spamkey' => 'spammaster',
            'spamvalue' => 'Spam Master: Action service called via license manual run.',
          ])->execute();
          // Spam action service.
          $spammaster_action_service = $this->actionService;
          $spammaster_action_service->spamMasterAct($spama);
        }
      }
    }
    // Store received data in module settings.
    $this->configFactory->getEditable('spammaster.settings')
      ->set('spammaster.license_key', $spammaster_license)
      ->save();
    // Store state values.
    $manual_values = [
      'spammaster.type' => $spammaster_type_set,
      'spammaster.license_status' => $spammaster_status,
      'spammaster.license_alert_level' => $spammaster_alert_level_received,
      'spammaster.license_protection' => $spammaster_protection_total_number,
      'spammaster.license_probability' => $spammaster_alert_level_p_text,
      'spammaster.spam_master_attached' => $spam_master_attached,
    ];
    $this->state->setMultiple($manual_values);

    // Display status to user.
    if ('INACTIVE' === $spammaster_status || 'MALFUNCTION_1' === $spammaster_status || 'MALFUNCTION_2' === $spammaster_status || 'MALFUNCTION_3' === $spammaster_status || 'MALFUNCTION_4' === $spammaster_status || 'MALFUNCTION_5' === $spammaster_status || 'MALFUNCTION_6' === $spammaster_status || 'MALFUNCTION_7' === $spammaster_status || 'MALFUNCTION_8' === $spammaster_status || 'UNSTABLE' === $spammaster_status || 'HIGH_VOLUME' === $spammaster_status || 'DISCONNECTED' === $spammaster_status || 'EXPIRED' === $spammaster_status) {
      $this->messenger->addError($this->t('License key @spammaster_license status is: @spammaster_status. Check Spam Master configuration page and read more about statuses.', [
        '@spammaster_license' => $spammaster_license,
        '@spammaster_status' => $spammaster_status,
      ]));
      // Spam Master log.
      $this->connection->insert('spammaster_keys')->fields([
        'date' => $spammaster_date,
        'spamkey' => 'spammaster-license',
        'spamvalue' => 'Spam Master: license manual status check: ' . $spammaster_status,
      ])->execute();
    }
    else {
      // Log message.
      $this->connection->insert('spammaster_keys')->fields([
        'date' => $spammaster_date,
        'spamkey' => 'spammaster-license',
        'spamvalue' => 'Spam Master: license manual status check: ' . $spammaster_status,
      ])->execute();
    }
  }

  /**
   * {@inheritdoc}
   */
  public function spamMasterLicDaily($spamKey, $spamCron) {

    // Get status variable.
    $spammaster_license_status = $this->state->get('spammaster.license_status');
    if ('VALID' === $spammaster_license_status || 'MALFUNCTION_1' === $spammaster_license_status || 'MALFUNCTION_2' === $spammaster_license_status) {
      // Colect data.
      $site_settings = $this->configFactory->getEditable('system.site');
      $spammaster_site_name = $site_settings->get('name');
      $spammaster_admin_email = $site_settings->get('mail');
      $spammaster_settings = $this->configFactory->getEditable('spammaster.settings');
      $spammaster_license = $spammaster_settings->get('spammaster.license_key');
      $spammaster_license_alert_level = $this->state->get('spammaster.license_alert_level');
      $spammaster_version = $this->state->get('spammaster.version');
      $spammaster_type = $this->state->get('spammaster.type');
      $spam_master_auto_update = $this->state->get('spammaster.spam_master_auto_update');
      $spam_master_db_protection_hash = $this->state->get('spammaster.spam_master_db_protection_hash');
      if (empty($spam_master_db_protection_hash)) {
        $spam_master_auto_update = 'false';
        $spam_master_db_protection_hash = substr(md5(uniqid(mt_rand(), TRUE)), 0, 64);
        if (empty($spam_master_db_protection_hash)) {
          $spam_master_db_protection_hash = 'md5-' . date('YmdHis');
        }
        $updated_values = [
          'spammaster.spam_master_auto_update' => $spam_master_auto_update,
          'spammaster.spam_master_db_protection_hash' => $spam_master_db_protection_hash,
        ];
        $this->state->setMultiple($updated_values);
      }
      // Prepare date.
      $spammaster_date = date('Y-m-d H:i:s');
      $spam_master_short_date = date('Y-m-d');
      $lazy_values = [
        'spammaster.spam_master_license_sync_date' => $spam_master_short_date,
        'spammaster.spam_master_license_sync_run' => '0',
      ];
      $this->state->setMultiple($lazy_values);
      $spammaster_platform = 'Drupal';
      $spammaster_platform_version = \Drupal::VERSION;
      $spammaster_platform_type = 'NO';
      $spammaster_n_websites = '0';
      $spammaster_multisite_joined = $spammaster_platform_type . ' - ' . $spammaster_n_websites;
      if (empty($spamCron)) {
        $spamCron = "EMP";
      }
      $spammaster_site_url = $this->requestStack->getCurrentRequest()->getHost();
      $address_unclean = $spammaster_site_url;
      $address = preg_replace('#^https?://#', '', $address_unclean);
      if (isset($_SERVER['SERVER_ADDR'])) {
        $spammaster_ip = substr($_SERVER['SERVER_ADDR'], 0, 48);
        // Should bot be localhost.
        if (empty($spammaster_ip) || '0' === $spammaster_ip || '127.0.0.1' === $spammaster_ip) {
          if (isset($_SERVER['SERVER_NAME'])) {
            $spam_master_ip_gethostbyname = gethostbyname($_SERVER['SERVER_NAME']);
            $spammaster_ip = substr($spam_master_ip_gethostbyname, 0, 48);
            if (empty($spam_master_ip_gethostbyname) || '0' === $spam_master_ip_gethostbyname) {
              $spam_master_urlparts = parse_url($spammaster_site_url);
              $spam_master_hostname_temp = $spam_master_urlparts['host'];
              $spam_master_result = dns_get_record($spam_master_hostname_temp, DNS_A);
              $spammaster_ip = substr($spam_master_result[0]['ip'], 0, 48);
            }
          }
          else {
            $spammaster_ip = 'I 000';
          }
        }
        $spammaster_hostname = substr(gethostbyaddr($_SERVER['SERVER_ADDR']), 0, 256);
        if (empty($spammaster_hostname) || '0' === $spammaster_hostname || '127.0.0.1' === $spammaster_hostname) {
          if (isset($_SERVER['SERVER_NAME'])) {
            $spam_master_ho_gethostbyname = gethostbyname($_SERVER['SERVER_NAME']);
            $spammaster_hostname = substr($spam_master_ho_gethostbyname, 0, 256);
            if (empty($spam_master_ho_gethostbyname) || '0' === $spam_master_ho_gethostbyname) {
              $spam_master_urlparts = parse_url($spammaster_site_url);
              $spam_master_hostname_temp = $spam_master_urlparts['host'];
              $spam_master_result = dns_get_record($spam_master_hostname_temp, DNS_A);
              $spammaster_hostname = substr($spam_master_result[0]['ip'], 0, 256);
            }
          }
          else {
            $spammaster_hostname = 'H 000';
          }
        }
      }
      else {
        if (isset($_SERVER['SERVER_NAME'])) {
          $spam_master_ip_gethostbyname = gethostbyname($_SERVER['SERVER_NAME']);
          $spammaster_ip = substr($spam_master_ip_gethostbyname, 0, 48);
          if (empty($spam_master_ip_gethostbyname) || '0' === $spam_master_ip_gethostbyname) {
            $spam_master_urlparts = parse_url($spammaster_site_url);
            $spam_master_hostname_temp = $spam_master_urlparts['host'];
            $spam_master_result = dns_get_record($spam_master_hostname_temp, DNS_A);
            $spammaster_ip = substr($spam_master_result[0]['ip'], 0, 48);
          }
          else {
            $spammaster_ip = 'I 001';
          }
          $spam_master_ho_gethostbyname = gethostbyname($_SERVER['SERVER_NAME']);
          $spammaster_hostname = substr($spam_master_ho_gethostbyname, 0, 256);
          if (empty($spam_master_ho_gethostbyname) || '0' === $spam_master_ho_gethostbyname) {
            $spam_master_urlparts = parse_url($spammaster_site_url);
            $spam_master_hostname_temp = $spam_master_urlparts['host'];
            $spam_master_result = dns_get_record($spam_master_hostname_temp, DNS_A);
            $spammaster_hostname = substr($spam_master_result[0]['ip'], 0, 256);
          }
          else {
            $spammaster_hostname = 'H 001';
          }
        }
        else {
          $spammaster_ip = 'I 002';
          $spammaster_hostname = 'H 002';
        }
      }

      // Get buffer count.
      $spammaster_buffer_size = $this->connection->select('spammaster_threats', 'u');
      $spammaster_buffer_size->fields('u', ['threat']);
      $spammaster_buffer_size_result = $spammaster_buffer_size->countQuery()->execute()->fetchField();
      if (empty($spammaster_buffer_size_result)) {
        $spammaster_buffer_size_result = '1';
      }
      // Get white count.
      $spammaster_white_size = $this->connection->select('spammaster_white', 'u');
      $spammaster_white_size->fields('u', ['white_']);
      $spammaster_white_size_result = $spammaster_white_size->countQuery()->execute()->fetchField();
      if (empty($spammaster_white_size_result)) {
        $spammaster_white_size_result = '0';
      }
      // Get logs count.
      $spammaster_spam_watch_query = $this->connection->select('spammaster_keys', 'u');
      $spammaster_spam_watch_query->fields('u', ['spamkey']);
      $spammaster_spam_watch_result = $spammaster_spam_watch_query->countQuery()->execute()->fetchField();
      if (empty($spammaster_spam_watch_result)) {
        $spammaster_spam_watch_result = '0';
      }

      // Encode ssl post link security.
      $spammaster_license_url = 'aHR0cHM6Ly93d3cuc3BhbW1hc3Rlci5vcmcvd3AtY29udGVudC9wbHVnaW5zL3NwYW0tbWFzdGVyLWFkbWluaXN0cmF0b3IvaW5jbHVkZXMvbGljZW5zZS9nZXRfbGljLnBocA==';

      // Call drupal hhtpclient.
      $client = $this->httpClient;
      // Post data.
      $request = $client->post(base64_decode($spammaster_license_url), [
        'form_params' => [
          'spam_license_key' => $spammaster_license,
          'platform' => $spammaster_platform,
          'platform_version' => $spammaster_platform_version,
          'platform_type' => $spammaster_multisite_joined,
          'spam_master_version' => $spammaster_version,
          'spam_master_type' => $spammaster_type,
          'blog_name' => $spammaster_site_name,
          'blog_address' => $address,
          'blog_email' => $spammaster_admin_email,
          'blog_hostname' => $spammaster_hostname,
          'blog_ip' => $spammaster_ip,
          'blog_up' => $spam_master_auto_update,
          'spam_master_db' => $spam_master_db_protection_hash,
          'spam_master_buffer' => $spammaster_buffer_size_result,
          'spam_master_white' => $spammaster_white_size_result,
          'spam_master_logs' => $spammaster_spam_watch_result,
          'spam_master_cron' => $spamCron,
        ],
      ]);
      // Decode json data.
      $response = Json::decode($request->getBody());
      if (empty($response)) {
        $spammaster_type_set = 'EMPTY';
        $spammaster_status = 'INACTIVE';
        $spammaster_protection_total_number = '0';
        $spammaster_alert_level_received = '';
        $spammaster_alert_level_p_text = '';
        $spam_master_attached = '';
      }
      else {
        $spammaster_status = $response['status'];
        if ('MALFUNCTION_3' === $spammaster_status) {
          $spammaster_type_set = 'MALFUNCTION_3';
          $spammaster_protection_total_number = 'MALFUNCTION_3';
          $spammaster_alert_level_received = 'MALFUNCTION_3';
          $spammaster_alert_level_p_text = 'MALFUNCTION_3';
          $spam_master_attached = '';
        }
        else {
          $spammaster_type_set = $response['type'];
          $spammaster_protection_total_number = $response['threats'];
          $spammaster_alert_level_received = $response['alert'];
          $spammaster_alert_level_p_text = $response['percent'];
          $spam_master_attached = $response['attached'];

          $spama = $response['a'];
          if ('1' === $spama) {
            $this->state->set('spammaster.new_options', '1');
            $this->connection->insert('spammaster_keys')->fields([
              'date' => $spammaster_date,
              'spamkey' => 'spammaster',
              'spamvalue' => 'Spam Master: Action service called via license cron.',
            ])->execute();
            // Spam action service.
            $spammaster_action_service = $this->actionService;
            $spammaster_action_service->spamMasterAct($spama);
          }
        }
      }
      // Store received data in module settings.
      $this->configFactory->getEditable('spammaster.settings')
        ->set('spammaster.license_key', $spammaster_license)
        ->save();
      // Store state values.
      $daily_values = [
        'spammaster.type' => $spammaster_type_set,
        'spammaster.license_status' => $spammaster_status,
        'spammaster.license_alert_level' => $spammaster_alert_level_received,
        'spammaster.license_protection' => $spammaster_protection_total_number,
        'spammaster.license_probability' => $spammaster_alert_level_p_text,
        'spammaster.spam_master_attached' => $spam_master_attached,
      ];
      $this->state->setMultiple($daily_values);

      // Call mail service for all requests.
      $spammaster_mail_service = $this->mailService;

      // Display status to user.
      if ('INACTIVE' === $spammaster_status || 'MALFUNCTION_1' === $spammaster_status || 'MALFUNCTION_2' === $spammaster_status || 'MALFUNCTION_3' === $spammaster_status || 'MALFUNCTION_4' === $spammaster_status || 'MALFUNCTION_5' === $spammaster_status || 'MALFUNCTION_6' === $spammaster_status || 'MALFUNCTION_7' === $spammaster_status || 'MALFUNCTION_8' === $spammaster_status || 'UNSTABLE' === $spammaster_status || 'HIGH_VOLUME' === $spammaster_status || 'DISCONNECTED' === $spammaster_status || 'EXPIRED' === $spammaster_status) {
        // Log message.
        $this->connection->insert('spammaster_keys')->fields([
          'date' => $spammaster_date,
          'spamkey' => 'spammaster-cron',
          'spamvalue' => 'Spam Master: cron license warning. Status: ' . $spammaster_status,
        ])->execute();

        // Call mail service function.
        $spammaster_mail_service->spamMasterLicMalfunctions();
      }
      if ('EXPIRED' === $spammaster_status) {
        // Log message.
        $this->connection->insert('spammaster_keys')->fields([
          'date' => $spammaster_date,
          'spamkey' => 'spammaster-cron',
          'spamvalue' => 'Spam Master: cron license warning. Status: ' . $spammaster_status,
        ])->execute();

        // Call mail service function.
        $spammaster_mail_service->spamMasterLicExpired();
      }
      if ('VALID' === $spammaster_status) {
        // Log message.
        $this->connection->insert('spammaster_keys')->fields([
          'date' => $spammaster_date,
          'spamkey' => 'spammaster-cron',
          'spamvalue' => 'Spam Master: cron license success. Status: ' . $spammaster_status,
        ])->execute();
      }
      if ('ALERT_3' === $spammaster_license_alert_level) {
        // Log message.
        $this->connection->insert('spammaster_keys')->fields([
          'date' => $spammaster_date,
          'spamkey' => 'spammaster-cron',
          'spamvalue' => 'Spam Master: cron alert level 3 detected.',
        ])->execute();

        // Call mail service function.
        $spammaster_mail_service->spamMasterLicAlertLevel3();
      }
    }
  }

}
